AndrossyDialog class

Inheritance

Constructors

AndrossyDialog({Key? key, bool barrierDismissible = true, Color? barrierColor, double barrierBlurSigma = 5, Duration? displayDuration, ValueChanged<Object?>? onDismiss, required AndrossyDialogBuilder builder})
const
AndrossyDialog.animated({Key? key, bool barrierDismissible = true, Color? barrierColor, double barrierBlurSigma = 5, Duration? displayDuration, Duration? duration, Duration? reverseDuration, Curve? curve, Curve? reverseCurve, ValueChanged<Object?>? onDismiss, AndrossyDialogPosition position = AndrossyDialogPosition.center, AndrossyDialogTransitionBuilder? transitionBuilder, required AndrossyDialogBuilder builder})
const

Properties

barrierBlurSigma double
final
barrierColor Color?
final
barrierDismissible bool
final
builder AndrossyDialogBuilder
final
curve Curve?
final
displayDuration Duration?
final
duration Duration?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDismiss ValueChanged<Object?>?
final
position AndrossyDialogPosition
final
reverseCurve Curve?
final
reverseDuration Duration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionBuilder AndrossyDialogTransitionBuilder?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AndrossyDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dismiss({bool? force, Object? result}) Future<void>
show<T>({required BuildContext context, required AndrossyDialogBuilder builder, bool material = true, bool animated = true, bool barrierDismissible = true, double barrierBlurSigma = 5.0, Color? barrierColor, String? barrierLabel, Curve? curve, Curve? reverseCurve, Duration? duration, Duration? reverseDuration, Duration? displayDuration, bool useSafeArea = false, bool useRootNavigator = true, RouteSettings? routeSettings, Offset? anchorPoint, AndrossyDialogPosition position = AndrossyDialogPosition.center, AndrossyDialogTransitionBuilder? transitionBuilder, TraversalEdgeBehavior? traversalEdgeBehavior, bool useModalBottomSheet = false, bool enableDrag = false, bool showDragHandle = false, bool isScrollControlled = false, AnimationStyle? sheetAnimationStyle, AnimationController? transitionAnimationController, double scrollControlDisabledMaxHeightRatio = 9.0 / 16.0, ShapeBorder? shape, double? elevation, Color? backgroundColor, BoxConstraints? constraints, ValueChanged<Object?>? onDismiss}) Future<T?>