DialogsHelper extension

Extension on BuildContext to simplify showing dialogs using the Dialogs class.

on

Methods

dismiss({bool? force, Object? result}) Future<void>

Available on BuildContext, provided by the DialogsHelper extension

hideLoader([bool force = false]) Future<void>

Available on BuildContext, provided by the DialogsHelper extension

Shows or hides a loader dialog with an optional loading status.
show<T>(String name, {DialogContent content = const DialogContent(id: "custom")}) Future<T?>

Available on BuildContext, provided by the DialogsHelper extension

showAlert({String? title, String? message, String? positiveButtonText, String? negativeButtonText, AlertDialogContent content = const AlertDialogContent()}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows an alert dialog with the provided title and message.
showEditor({String? title, String? subtitle, String? hint, String? text, EditableDialogContent content = const EditableDialogContent()}) Future<String?>

Available on BuildContext, provided by the DialogsHelper extension

Shows an editable dialog for user input with the provided title, initial text, and hint.
showEditorSheet({String? title, String? subtitle, String? hint, String? text, EditableDialogContent content = const EditableDialogContent()}) Future<String?>

Available on BuildContext, provided by the DialogsHelper extension

Shows an editable sheet for user input with the provided title, initial text, and hint.
showErrorSnackBar(String message, {String? title, SnackBarContent content = const SnackBarContent(id: "error_snack_bar")}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows an error-themed SnackBar with the provided error message.
showInfoSnackBar(String message, {String? title, SnackBarContent content = const SnackBarContent(id: "info_snack_bar")}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows a warning-themed SnackBar with the provided warning message.
showLoader({Alignment? alignment, bool? barrierDismissible, Color? barrierColor, double? barrierBlurSigma, Curve? curve, Curve? reverseCurve, Duration? duration, Duration? reverseDuration, Object? args, WidgetBuilder? builder, LoaderTransitionBuilder? transitionBuilder}) → void

Available on BuildContext, provided by the DialogsHelper extension

Shows or hides a loader dialog with an optional loading status.
showMessage(String? message, {String? title, MessageDialogContent content = const MessageDialogContent()}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows a message dialog with the provided message and optional title.
showOptions<T extends Object?>({int initialIndex = 0, List<String>? options, String? title, String? subtitle, OptionDialogContent<Object?> content = const OptionDialogContent()}) Future<int>

Available on BuildContext, provided by the DialogsHelper extension

Shows a Options with the provided some options.
showOptionsSheet<T extends Object?>({int initialIndex = 0, List<String>? options, String? title, String? subtitle, OptionDialogContent<Object?> content = const OptionDialogContent()}) Future<int>

Available on BuildContext, provided by the DialogsHelper extension

Shows a Options with the provided some options.
showSnackBar(String message, {String? title, SnackBarContent content = const SnackBarContent()}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows a SnackBar with the provided message.
showToast(String msg, {Duration? duration, Alignment? alignment, Object? args, Widget? custom}) → void

Available on BuildContext, provided by the DialogsHelper extension

Displays a custom toast-like overlay message.
showWaitingSnackBar(String message, {String? title, SnackBarContent content = const SnackBarContent(id: "waiting_snack_bar")}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows a warning-themed SnackBar with the provided warning message.
showWarningSnackBar(String message, {String? title, SnackBarContent content = const SnackBarContent(id: "warning_snack_bar")}) Future<bool>

Available on BuildContext, provided by the DialogsHelper extension

Shows a warning-themed SnackBar with the provided warning message.