MessageDialogConfig class
- Inheritance
-
- Object
- DialogConfig<
MessageDialogContent> - MessageDialogConfig
Constructors
-
MessageDialogConfig({required AndrossyDialogContentBuilder<
MessageDialogContent> builder, bool useSafeArea = false, RouteSettings? routeSettings, Offset? anchorPoint, TraversalEdgeBehavior? traversalEdgeBehavior, String? barrierLabel, bool material = true, bool animated = true, bool barrierDismissible = true, Color? barrierColor, double barrierBlurSigma = 5.0, Curve? curve, Curve? reverseCurve, Duration? displayDuration, Duration? duration, Duration? reverseDuration, AndrossyDialogPosition position = AndrossyDialogPosition.center, AndrossyDialogTransitionBuilder? transitionBuilder}) -
const
Properties
- anchorPoint → Offset?
-
finalinherited
- animated → bool
-
finalinherited
- backgroundColor → Color?
-
finalinherited
- barrierBlurSigma → double
-
finalinherited
- barrierColor → Color?
-
finalinherited
- barrierDismissible → bool
-
finalinherited
- barrierLabel → String?
-
finalinherited
-
builder
→ AndrossyDialogContentBuilder<
MessageDialogContent> -
finalinherited
- constraints → BoxConstraints?
-
finalinherited
- curve → Curve?
-
finalinherited
- displayDuration → Duration?
-
finalinherited
- duration → Duration?
-
finalinherited
- elevation → double?
-
finalinherited
- enableDrag → bool
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isScrollControlled → bool
-
finalinherited
- material → bool
-
finalinherited
- position → AndrossyDialogPosition
-
finalinherited
- reverseCurve → Curve?
-
finalinherited
- reverseDuration → Duration?
-
finalinherited
- routeSettings → RouteSettings?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollControlDisabledMaxHeightRatio → double
-
finalinherited
- shape → ShapeBorder?
-
finalinherited
- sheetAnimationStyle → AnimationStyle?
-
finalinherited
- showDragHandle → bool
-
finalinherited
- transitionAnimationController → AnimationController?
-
finalinherited
- transitionBuilder → AndrossyDialogTransitionBuilder?
-
finalinherited
- traversalEdgeBehavior → TraversalEdgeBehavior?
-
finalinherited
- useModalBottomSheet → bool
-
finalinherited
-
finalinherited
- useSafeArea → bool
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited